#ifndef __VERSION_H
#define __VERSION_H
/*-------------------------------------------------------------------------
 * Copyright (c) 2000-2002 Kenneth W. Sodemann (stuffle@charter.net)
 *-------------------------------------------------------------------------
 * $Id: version.h,v 1.2 2002/01/30 00:40:02 stuffle Exp $
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to
 * Free Software Foundation, Inc.
 * 59 Temple Place, Suite 330 
 * Boston, MA  02111-1307  USA
 *-------------------------------------------------------------------------
 */
/*! \file version.h

  \brief A collection of utilities used to determine version information.

  These functions determine version information for libPRepS.

  \author Kenneth W. Sodemann (stuffle@charter.net)
  $Revision: 1.2 $
  $Date: 2002/01/30 00:40:02 $
*/

/* 
 * __BEGIN_DECLS should be used at the beginning of your declarations,
 * so that C++ compilers don't mangle their names.  Use __END_DECLS at
 * the end of C declarations. 
 */
#undef __BEGIN_DECLS
#undef __END_DECLS
#ifdef __cplusplus
# define __BEGIN_DECLS extern "C" {
# define __END_DECLS }
#else
# define __BEGIN_DECLS /* empty */
# define __END_DECLS /* empty */
#endif

/* 
 * __P is a macro used to wrap function prototypes, so that compilers
 * that don't understand ANSI C prototypes still work, and ANSI C
 * compilers can issue warnings about type mismatches. 
 */
#undef __P
#if defined (__STDC__) || defined (_AIX) \
        || (defined (__mips) && defined (_SYSTYPE_SVR4)) \
                        || defined(WIN32) || defined(__cplusplus)
# define __P(protos) protos
#else
# define __P(protos) ()
#endif

__BEGIN_DECLS
/*! \fn libpreps_major_version (void)

 \brief return the major version of libPRepS. 

 \return
 The major libPRepS version number. 
*/
int libpreps_major_version __P((void));

/*! \fn libpreps_minor_version (void)

 \brief return the minor version of libPRepS. 

 \return
 The minor libPRepS version number. 
*/
int libpreps_minor_version __P((void));

/*! \fn libpreps_micro_version (void)

 \brief return the micro version of libPRepS. 

 \return
 The micro libPRepS version number. 
*/
int libpreps_micro_version __P((void));

__END_DECLS
#endif
